=================
How to contribute
=================

🎉👍 First things first, thank you for considering contributing to *smif*!

Getting started
---------------

Please `raise an issue`_ for bugs spotted and features proposed.

Github `pull requests`_ can be made against the master branch so long as we
continue prototyping before a v1.0 release.

See the `developer documentation`_ for details of testing and other conventions.

.. _developer documentation: http://smif.readthedocs.io/en/latest/developers.html
.. _pull requests: https://help.github.com/articles/about-pull-requests/
.. _raise an issue: https://github.com/nismod/smif/issues
